# Native Providers

This directory holds native providers that are shipped with tackle by default. They form the core functionalities that are extended by

TODO: Create table of contents here with some notes about development of each provider. This is for developers who want to contribute to providers

## Development standards

- Native providers can not have any additional requirements and should not wrap external applications
- Hooks should be as general as possible wrapping basic functionalities that can be composed to build higher level logic
- Hooks should be grouped into their appropriate provider
-


